<p align="center">
  <a href="http://nestjs.com/" target="blank"><img src="https://nestjs.com/img/logo-small.svg" width="120" alt="Nest Logo" /></a>
</p>

  <p align="center">Powerful, MTProto API framework in Python for users and bots</p>
    <p align="center">
<!-- <p align='center'>
  <img alt="GitHub Sparkline" src="https://github.com/gramscript/gramscript">
</p> -->
<a href="https://www.npmjs.com/~nestjscore" target="_blank"><img alt="GitHub code size in bytes" src="https://img.shields.io/github/languages/code-size/gramscript/gramscript?logo=files&logoColor=f72585"></a>
<a href="https://www.codefactor.io/repository/github/gramscript/gramscript.py/overview/main"><img src="https://www.codefactor.io/repository/github/gramscript/gramscript.py/badge/main" alt="CodeFactor" /></a>
<a href="https://github.com/gramscript/gramscript.py" target="_blank"><img alt="GitHub issues" src="https://img.shields.io/github/issues-raw/gramscript/gramscript?color=8eecf5&logo=anaconda&logoColor=06d6a0"></a>
<a href="https://github.com/gramscript/gramscript.py" target="_blank"><img alt="GitHub" src="https://img.shields.io/github/license/gramscript/gramscript?logo=adguard&logoColor=390099"></a>
<a href="https://github.com/gramscript/gramscript.py" target="_blank"><img alt="GitHub Repo stars" src="https://img.shields.io/github/stars/gramscript/gramscript?color=90e0ef&logoColor=ff4d6d"></a>
<a href="https://github.com/gramscript/gramscript.py"><img alt="GitHub last commit" src="https://img.shields.io/github/last-commit/gramscript/gramscript?logo=electron&logoColor=89fc00"></a>
<a href="https://pypi.org/project/gramscript/"><img alt="PyPI" src="https://img.shields.io/pypi/v/gramscript?logo=adguard&logoColor=89fc00"></a>
<a href="https://github.com/gramscript/gramscript.py"><img alt="GitHub" src="https://img.shields.io/github/license/gramscript/gramscript.py?logo=adguard&logoColor=89fc00"></a>
<a href="https://pypi.org/project/gramscript"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/gramscript?color=06d6a0&logo=adguard&logoColor=89fc00"></a>
<a href="https://github.com/gramscript/gramscript.py"><img alt="GitHub contributors" src="https://img.shields.io/github/contributors/gramscript/gramscript.py?color=06d6a0&logo=adguard&logoColor=89fc00"></a>
<a href="https://pypi.org/project/gramscript/"><img alt="PyPI - Format" src="https://img.shields.io/pypi/format/gramscript"></a>
<a href="https://github.com/gramscript/gramscript.py"><img alt="Sourcegraph for Repo Reference Count" src="https://img.shields.io/sourcegraph/rrc/https://github.com/gramscript/gramscript.py"></a>
<a href="https://github.com/gramscript/gramscript.py"><img alt="Maintenance" src="https://img.shields.io/maintenance/yes/2022"></a>

## Description

Gramscript is a framework for building efficient, scalable <a href="http://t.me" target="_blank">Telegram</a> server-side applications. It uses modern 

<p>Under the hood, Nest makes use of <a href="https://expressjs.com/" target="_blank">Express</a>, but also, provides compatibility with a wide range of other libraries, like e.g. <a href="https://github.com/fastify/fastify" target="_blank">Fastify</a>, allowing for easy use of the myriad third-party plugins which are available.</p>


## Getting started

* To check out the [guide](https://gramscript.github.io/docs), visit [https://gramscript.git.io/](https://gramscript.github.io/). :books:
* 要查看中文 [指南](readme_zh.md), 请访问 [https://gramscript.github.io/docs/zh](https://gramscript.github.io/docs/zh). :books:
* [가이드](readme_kr.md) 문서는 [https://gramscript.github.io/docs/kr](https://gramscript.github.io/docs/kr)에서 확인하실 수 있습니다. :books:
* [ガイド](readme_jp.md)は [https://gramscript.github.io/docs/jp](https://gramscript.github.io/docs/jp)でご確認ください。 :books:

## Questions

For questions and support please use the [Discussions Page](https://github.com/gramscript/gramscript.py/discussions). The issue list of this repo is **exclusively** for bug reports and feature requests.

## Issues

Please make sure to read the [Issue Reporting Checklist](https://github.com/gramscript/gramscript.py/blob/master/CONTRIBUTING.md#-submitting-an-issue) before opening an issue. Issues not conforming to the guidelines may be closed immediately.

## Support

gramscript is an MIT-licensed open source project. It can grow thanks to the sponsors and support from the amazing backers. If you'd like to join them, please [read more here](https://gramscript.github.io/sponsors).


<!-- ### Sponsors

<table><tr><td align="center" valign="middle">
</table>

## Backers -->

## Stay in touch

* Author - [Kalanakt](https://github.com/kalanakt)
* Website - [https://gramscript.git.io](https://gramscript.github.io/)
* Github - [@gramscript](https://github.com/gramscript/)

## License

Gramscript is [MIT licensed](LICENSE).
